@@ -1,6 +1,6 @@
 package SPVM::Sys;
 
-our $VERSION = "0.486";
+our $VERSION = "0.487";
 
 1;
 
@@ -234,7 +234,9 @@ Gets the process number of the running this program. The same as the Perl L<$$|h
 
   static method stat : Sys::IO::Stat ($path : string);
 
-Returns a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object giving the status info for a file. The same as the Perl L<stat|https://perldoc.perl.org/functions/stat> function.
+Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<stat||SPVM::Sys::IO::Stat/"stat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
+
+And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
 
 =head2 chdir
 
@@ -318,7 +320,7 @@ Returns the value of a symbolic link. The same as the Perl L<readlink|https://pe
 
   static method symlink : int ($oldpath : string, $newpath : string);
 
-Creates a $newpath symbolically linked to the $oldpath. The same as the Perl L<symlink|https://perldoc.perl.org/functions/symlink> function.
+Creates a $newpath symbolically linked to $oldpath. The same as the Perl L<symlink|https://perldoc.perl.org/functions/symlink> function.
 
 If succeed, returns 1.
 
@@ -340,15 +342,15 @@ Calls the L<ioctl|SPVM::Sys::Ioctl/"ioctl"> method in the L<Sys::Ioctl|SPVM::Sys
 
   static method select : int ($readfds : Sys::Select::Fd_set, $writefds : Sys::Select::Fd_set, $exceptfds : Sys::Select::Fd_set, $timeout : Sys::Time::Timeval);
 
-Calls the L<select|SPVM::Sys::Select/"select"> method in the L<Sys::Select|SPVM::Sys::Select> class with the $ndfs set to 1024.
+Calls the L<select|SPVM::Sys::Select/"select"> method in the L<Sys::Select|SPVM::Sys::Select> class with $ndfs set to 1024.
 
 =head2 bind
 
   static method bind : int ($sockfd : int, $addr : Sys::Socket::Sockaddr);
 
-The next argument $addrlen is set to the size of the $addr.
+The next argument $addrlen is set to the size of $addr.
 
-Calls the L<bind|SPVM::Sys::Socket/"bind"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with the $addrlen.
+Calls the L<bind|SPVM::Sys::Socket/"bind"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $addrlen.
 
 If succeed, returns 1.
 
@@ -367,7 +369,7 @@ If succeed, returns 1.
 The next argument $addrlen is set to 128.
 
 Calls the L<accept|SPVM::Sys::Socket/"accept"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $addrlen,
-and returns the $addr.
+and returns $addr.
 
 The original return value is set to $$new_sockfd_ref.
 
@@ -375,9 +377,9 @@ The original return value is set to $$new_sockfd_ref.
 
   static method connect : int ($sockfd : int, $addr : Sys::Socket::Sockaddr);
 
-The next argument $addrlen is set to the size of the $addr.
+The next argument $addrlen is set to the size of $addr.
 
-Calls the L<connect|SPVM::Sys::Socket/"connect"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with the $addrlen.
+Calls the L<connect|SPVM::Sys::Socket/"connect"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $addrlen.
 
 If succeed, returns 1.
 
@@ -427,7 +429,7 @@ If succeed, returns 1.
 
   static method socket : void ($sockfd_ref : int*, $domain : int, $type : int, $protocol : int);
 
-Calls the L<socket|SPVM::Sys::Socket/"socket"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with the $domain, $type, $protocal,
+Calls the L<socket|SPVM::Sys::Socket/"socket"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $domain, $type, $protocal,
 and the return value is set to $$sockfd_ref.
 
 =head2 socketpair
@@ -436,8 +438,8 @@ and the return value is set to $$sockfd_ref.
 
 Creates a new int array with the length 2 for the next argument $pair.
 
-Calls the L<socketpair|SPVM::Sys::Socket/"socketpair"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with the $pair,
-and the $$sock_fd1_ref is set the first element of the $pair, and the $$sock_fd2_ref is set the second element of the $pair, nad 
+Calls the L<socketpair|SPVM::Sys::Socket/"socketpair"> method in the L<Sys::Socket|SPVM::Sys::Socket> class with $pair,
+and the $$sock_fd1_ref is set the first element of $pair, and the $$sock_fd2_ref is set the second element of $pair, nad 
 
 If succeed, returns 1.
 
@@ -445,18 +447,18 @@ If succeed, returns 1.
 
   static method setsockopt : int ($sockfd : int, $level : int, $optname : int, $optval : object of string|Int);
 
-If the $optval is the L<Int|SPVM::Int> type, a string for the next argument $optval is created by the length 4.
+If $optval is the L<Int|SPVM::Int> type, a string for the next argument $optval is created by the length 4.
 
-If the $optval is the string type, a string that for the next argument $optval is created by the length of the $optval.
+If $optval is the string type, a string that for the next argument $optval is created by the length of $optval.
 
 Calls the L<getsockopt|SPVM::Sys::Socket/"getsockopt"> method in the L<Sys::Socket|SPVM::Sys::Socket> class
-with the $optval and $optlen.
+with $optval and $optlen.
 
 If succeed, returns 1.
 
 Exceptions:
 
-The $optval must be defined. Otherwise an exception is thrown.
+$optval must be defined. Otherwise an exception is thrown.
 
 The type of $optval must be Int or string. Otherwise an exception is thrown.
 
@@ -464,16 +466,148 @@ The type of $optval must be Int or string. Otherwise an exception is thrown.
 
   static method getsockopt : string ($sockfd : int, $level : int, $optname : int, $optlen : int = -1);
 
-If the $optlen is less than 0, it is set to 4.
+If $optlen is less than 0, it is set to 4.
 
 A string for the next argument $optval is created by the length $optlen.
 
 Calls the L<getsockopt|SPVM::Sys::Socket/"getsockopt"> method in the L<Sys::Socket|SPVM::Sys::Socket> class
-with the $optval and $optlen, and the $optval set by this method is returnd.
+with $optval and $optlen, and $optval set by this method is returnd.
 
-=head1 Modules
+=head2 truncate
 
-All modules included in this distribution. These classes have methods that directly correspond to Linux/Unix/Mac or Windows system call functions written in C. In addition, several helper methods are implemented.
+  static method truncate : int ($fd : int, $legnth : long);
+
+Calls the L<ftruncate|SPVM::Sys::IO/"ftruncate"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+If succeed, returns 1.
+
+=head2 sysread
+
+  static method sysread : int ($fd : int, $buf : mutable string, $count : int, $buf_offset : int = 0);
+
+Calls the L<read|SPVM::Sys::IO/"read"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 syswrite
+
+  static method syswrite : int ($fd : int, $buf : string, $count : int = -1, $buf_offset : int = 0);
+
+Calls the L<write|SPVM::Sys::IO/"write"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 eof
+
+  static method eof : int ($stream : Sys::IO::Stream);
+
+Calls the L<feof|SPVM::Sys::IO/"feof"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 fileno
+
+  static method fileno : int ($stream : Sys::IO::Stream);
+
+Calls the L<fileno|SPVM::Sys::IO/"fileno"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 readline
+
+  static method readline : mutable string ($stream : Sys::IO::FileStream);
+
+Calls the L<readline|SPVM::Sys::IO/"readline"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 getc
+
+  static method getc : int ($stream : Sys::IO::FileStream);
+
+Calls the L<getc|SPVM::Sys::IO/"getc"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 flock
+
+  static method flock : int ($fd : int, $operation : int);
+
+Calls the L<flock|SPVM::Sys::IO/"flock"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+If succeed, returns 1.
+
+=head2 print
+
+  static method print : int ($stream : Sys::IO::FileStream, $string : string);
+
+Calls the L<fwrite|SPVM::Sys::IO/"fwrite"> method in the L<Sys::IO|SPVM::Sys::IO> class given the length of $string.
+
+If succeed, returns 1.
+
+=head2 printf
+
+  static method printf : int ($stream, $format : string, $args : object[])
+
+Calls the L</"print"> method after creating formatted string given $stream and $args using the L<sprintf|SPVM::Format/"sprintf"> method in the L<Format|SPVM::Format> class.
+
+=head2 read
+
+  static method read : int ($stream : Sys::IO::FileStream, $buf : mutable string, $count : int, $buf_offset : int = 0);
+
+Calls the L<fread|SPVM::Sys::IO/"fread"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 rewinddir
+
+  static method rewinddir : void ($dirp : Sys::IO::DirStream);
+
+Calls the L<rewinddir|SPVM::Sys::IO/"rewinddir"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 readdir
+
+  static method readdir : Sys::IO::Dirent ($dirp : Sys::IO::DirStream);
+
+Calls the L<readdir|SPVM::Sys::IO/"readdir"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 seek
+
+  static method seek : int ($stream : Sys::IO::FileStream, $offset : long, $whence : int);
+
+Calls the L<fseek|SPVM::Sys::IO/"fseek"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+If succeed, returns 1.
+
+=head2 sysseek
+
+  static method sysseek : long ($fd : int, $offset : long, $whence : int);
+
+Calls the L<lseek|SPVM::Sys::IO/"lseek"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+If succeed, returns 1.
+
+=head2 tell
+
+  static method tell : long ($stream : Sys::IO::FileStream);
+
+Calls the L<ftell|SPVM::Sys::IO/"ftell"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 telldir
+
+  static method telldir : long ($dirp : Sys::IO::DirStream);
+
+Calls the L<telldir|SPVM::Sys::IO/"telldir"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 lstat
+
+  static method lstat : Sys::IO::Stat ($path : string);
+
+Creates a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object and calls the L<lstat|SPVM::Sys::IO::Stat/"lstat"> method in the L<Sys::IO::Stat|SPVM::Sys::IO::Stat> class.
+
+And returns the a L<Sys::IO::Stat|SPVM::Sys::IO::Stat> object.
+
+=head2 utime
+
+  static method utime : int ($atime : long, $mtime : long, $filename : string);
+
+Unless $atime < 0 and $mtime < 0, creates a L<Sys::IO::Utimbuf|SPVM::Sys::IO::Utimbuf> object.
+
+And calls the L<utime|SPVM::Sys::IO/"utime"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+=head2 chown
+
+  static method chown : int ($owner : int, $group : int, $path : string);
+
+Calls the L<chown|SPVM::Sys::IO/"chown"> method in the L<Sys::IO|SPVM::Sys::IO> class.
+
+If succeed, returns 1.
 
 =head2 Sys::Env
 
