@@ -10,12 +10,12 @@ static const char* FILE_NAME = "Sys/Time/Timeval.c";
 
 int32_t SPVM__Sys__Time__Timeval__new(SPVM_ENV* env, SPVM_VALUE* stack) {
 
-  int32_t e;
+  int32_t error_id = 0;
   
   struct timeval* st_tv = env->new_memory_stack(env, stack, sizeof(struct timeval));
   
-  void* obj_tv = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timeval", st_tv, &e, __func__, FILE_NAME, __LINE__);
-  if (e) { return e; }
+  void* obj_tv = env->new_pointer_object_by_name(env, stack, "Sys::Time::Timeval", st_tv, &error_id, __func__, FILE_NAME, __LINE__);
+  if (error_id) { return error_id; }
 
   stack[0].oval = obj_tv;
   
